<?php

/**
 * Gestion du formulaire d'administration des feeds d'un plugin utilisateur.
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Chargement du formulaire d'administration des feeds.
 * Il est obligatoire de fournir un préfixe de plugin utilisateur sinon le formulaire n'est pas utilisable.
 *
 * @param string      $plugin       Préfixe du plugin utilisateur
 * @param null|string $categorie_id Identifiant de la catégorie ou vide si on veut afficher tous les feeds
 * @param null|string $feed_id      Identificant du feed servant à l'affichage du bloc de détails
 *
 * @return array Environnement du formulaire
 **/
function formulaires_admin_feeds_charger_dist(string $plugin, ?string $categorie_id = '', ?string $feed_id = '') {
	$valeurs = [];

	if (autoriser('voir', '_feeds', '', null, ['plugin' => $plugin])) {
		$valeurs['plugin'] = $plugin;
		if ($categorie_id) {
			$valeurs['category'] = $categorie_id;
		}
		$valeurs['feed_id'] = $feed_id;
	} else {
		$valeurs['message_erreur'] = _T('ezmashup:erreur_feed_admin_noaccess');
		$valeurs['editable'] = false;
	}

	return $valeurs;
}

/**
 * Traitement du formulaire d'administration des feeds.
 *
 * @param string      $plugin       Préfixe du plugin utilisateur
 * @param null|string $categorie_id Identifiant de la catégorie ou vide si on veut afficher tous les feeds
 * @param null|string $feed_id      Identificant du feed servant à l'affichage du bloc de détails
 *
 * @return array Retourn du traitement : rien de spécial car pour l'instant, il n'est pas utilisé
 **/
function formulaires_admin_feeds_traiter_dist(string $plugin, ?string $categorie_id = '', ?string $feed_id = '') {
	$retour = [];

	$action_feed = '';
	$id_feed = '';
	if ($action = _request('vider')) {
		$action_feed = 'vider_feed';
		$id_feed = key($action);
	} elseif ($action = _request('executer')) {
		$action_feed = 'executer_feed';
		$id_feed = key($action);
	}

	if (
		$action_feed
		and $id_feed
	) {
		$actionner = charger_fonction(
			$action_feed,
			'action',
			true
		);
		$retour_action = $actionner("{$plugin}:{$id_feed}");
		$parametres = $retour_action['parameters'] ?? [];
		if ($retour_action['level'] === _LOG_ERREUR) {
			// On affiche un message d'erreur simple suivi par l'erreur exacte remontée du traitement. Ce complément
			// est affiché en italique
			$message_erreur = ($action_feed === 'executer_feed')
				? _T('ezmashup:notice_feed_exec_nok', $parametres)
				: _T('ezmashup:notice_feed_empty_nok', $parametres);
			$retour['message_erreur'] = $message_erreur
				. '<br />'
				. '<i>(' . _T('ezmashup:' . $retour_action['code'], $parametres) . ')</i>';
		} else {
			// On affiche le message correspondant à l'information remontée du traitement
			$retour['message_ok'] = _T('ezmashup:' . $retour_action['code'], $parametres);
		}
	}

	$retour['editable'] = true;

	return $retour;
}
